@@ -17,8 +17,8 @@ from .tools import (
 class BaseDataManager(object):
     model: Any = None
     serializer: Any = None
-    default_limit: int = 1000
-    split_files: bool = True
+    default_limit: int = 150000
+    query_limit: int = 1000
 
     def __init__(self, integration_id: int, date_from: str, date_to: str):
         self.integration_id = integration_id
@@ -40,7 +40,7 @@ class BaseDataManager(object):
     def get_count(self) -> int:
         raise NotImplementedError('get_count must be implemented.')
 
-    def get_data(self) -> int:
+    def get_data(self, skip: int = 0, **kwargs) -> list:
         raise NotImplementedError('get_data must be implemented.')
 
     def get_default_serializer_fields(self) -> list:
@@ -51,57 +51,44 @@ class BaseDataManager(object):
     def serialize_data(self, data: Any, fields: list) -> Union[Generator, list, dict]:
         raise NotImplementedError('serialize_data must be implemented.')
 
-    def _generate_split_result(self, filename: str, fields: list,) -> dict:
-        skip = 0
-        part = 0
-        count = self.get_count()
-        links = []
-        while skip <= count:
-            part += 1
-            part_filename = f'{filename}_{part}'
-            s3_filename = f"{part_filename}.tsv"
-            if check_file_exist(s3_filename):
-                skip += self.default_limit
-                links.append(get_file_link(s3_filename))
-                continue
-            db_data = self.get_data()
-            data = self.serialize_data(db_data, fields)
-            filename = write_file(s3_filename, data, fieldnames=fields, delimiter='\t')
-            s3_file_data = upload_to_s3(filename)
-            links.append(get_file_link(s3_file_data['s3_filename']))
-            delete_file(s3_filename)
-            skip += self.default_limit
-        return {'links': links}
-
-    def _generate_result(
-        self, filename: str, fields: Optional[list] = None,
-    ):
-        skip = 0
-        links = []
-        s3_filename = f"{filename}.tsv"
+    def _generate_file(self, skip: int, s3_filename: str, fields: list) -> str:
         if check_file_exist(s3_filename):
-            links.append(get_file_link(s3_filename))
-            return {'links': links}
+            skip += self.default_limit
+            return get_file_link(s3_filename)
         with open(s3_filename, 'w') as f:
             writer = csv.DictWriter(f, delimiter='\t', fieldnames=fields)
             writer.writeheader()
             while True:
-                qs = self.get_data()[skip : skip + self.default_limit]
+                qs = self.get_data()
                 if not qs:
                     break
                 data = self.serialize_data(qs, fields)
                 for row in data:
                     writer.writerow(row)
-                skip += self.default_limit
+                skip += self.query_limit
         s3_file_data = upload_to_s3(s3_filename)
-        links.append(get_file_link(s3_file_data['s3_filename']))
-        delete_file(s3_filename)
+        return get_file_link(s3_file_data['s3_filename'])
+
+    def _generate_result(self, filename: str, fields: list) -> dict:
+        skip = 0
+        part = 0
+        count = self.get_count()
+        links = []
+        if self.default_limit >= count:
+            links.append(self._generate_file(skip, f'{filename}.tsv', fields))
+            delete_file(f'{filename}.tsv')
+        else:
+            while skip <= count:
+                while skip <= self.default_limit:
+                    part += 1
+                    part_filename = f'{filename}_{part}'
+                    s3_filename = f"{part_filename}.tsv"
+                    links.append(self._generate_file(skip, f'{filename}.tsv', fields))
+                    delete_file(s3_filename)
         return {'links': links}
 
     def generate(self, filename: str, fields: Optional[list] = None) -> dict:
         fields: list = fields if fields else self.get_default_serializer_fields()
-        if self.split_files:
-            return self._generate_split_result(filename=filename, fields=fields)
         return self._generate_result(filename=filename, fields=fields)
 
 
